==> micronaut-hibernate-jpa-2.3.3-sources.jar: io/micronaut/configuration/hibernate/jpa/TransactionalSessionInterceptor.java <==
/*
 * Copyright 2017-2020 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.configuration.hibernate.jpa;

import io.micronaut.aop.MethodInterceptor;
import io.micronaut.aop.MethodInvocationContext;
import io.micronaut.context.BeanContext;
import io.micronaut.context.Qualifier;
import io.micronaut.context.annotation.Prototype;
import io.micronaut.core.annotation.Internal;
import io.micronaut.inject.ExecutableMethod;
import org.hibernate.Session;
import org.hibernate.SessionFactory;

/**
 * An interceptor that uses the current active session.
 *
 * @author graemerocher
 * @since 2.0
 * @see TransactionalSession
 * @see TransactionalSessionAdvice
 */
@Internal
@Prototype
class TransactionalSessionInterceptor implements MethodInterceptor<Session, Object> {

    private final SessionFactory sessionFactory;

    /**
     * Default constructor.
     *
     * @param beanContext The bean context
     * @param qualifier   The qualifier
     */
    @Internal
    TransactionalSessionInterceptor(BeanContext beanContext, Qualifier<SessionFactory> qualifier) {
        this.sessionFactory = beanContext.getBean(SessionFactory.class, qualifier);
    }

    @Override
    public Object intercept(MethodInvocationContext<Session, Object> context) {
        final ExecutableMethod<Session, Object> method = context.getExecutableMethod();
        return method.invoke(sessionFactory.getCurrentSession(), context.getParameterValues());
    }
}

==> micronaut-hibernate-jpa-5.0.1-sources.jar: io/micronaut/configuration/hibernate/jpa/TransactionalSessionInterceptor.java <==
/*
 * Copyright 2017-2020 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.micronaut.configuration.hibernate.jpa;

import io.micronaut.aop.InterceptorBean;
import io.micronaut.aop.MethodInterceptor;
import io.micronaut.aop.MethodInvocationContext;
import io.micronaut.context.BeanContext;
import io.micronaut.context.Qualifier;
import io.micronaut.context.annotation.Prototype;
import io.micronaut.core.annotation.Internal;
import io.micronaut.inject.ExecutableMethod;
import org.hibernate.Session;
import org.hibernate.SessionFactory;

/**
 * An interceptor that uses the current active session.
 *
 * @author graemerocher
 * @since 2.0
 * @see TransactionalSession
 * @see TransactionalSessionAdvice
 */
@Internal
@Prototype
@InterceptorBean(TransactionalSessionAdvice.class)
class TransactionalSessionInterceptor implements MethodInterceptor<Session, Object> {

    private final SessionFactory sessionFactory;

    /**
     * Default constructor.
     *
     * @param beanContext The bean context
     * @param qualifier   The qualifier
     */
    @Internal
    TransactionalSessionInterceptor(BeanContext beanContext, Qualifier<SessionFactory> qualifier) {
        this.sessionFactory = beanContext.getBean(SessionFactory.class, qualifier);
    }

    @Override
    public Object intercept(MethodInvocationContext<Session, Object> context) {
        final ExecutableMethod<Session, Object> method = context.getExecutableMethod();
        if (method.getName().equals("close") && method.getArguments().length == 0) {
            // close handled by transaction management, ignore
            return null;
        } else {
            return method.invoke(sessionFactory.getCurrentSession(), context.getParameterValues());
        }
    }
}
